Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrecht Van Lommel <brechtvanlommel@gmail.com>2019-01-22 21:59:27 +0300
committerBrecht Van Lommel <brechtvanlommel@gmail.com>2019-01-22 22:00:13 +0300
commit1ddf93a706d7f914e7bab20083e40130ce60455b (patch)
treeadd7d8673b13c8178257b82dcdc84f828b91997d /source/blender/blenloader
parentfa5ce915df299ea917bf014749cc905fa1e2028e (diff)
Defaults: don't use Filmic view transform in Video Editing template.
It's too slow for now, could be considered if it's optimized more.
Diffstat (limited to 'source/blender/blenloader')
-rw-r--r--source/blender/blenloader/intern/versioning_defaults.c8
1 files changed, 6 insertions, 2 deletions
diff --git a/source/blender/blenloader/intern/versioning_defaults.c b/source/blender/blenloader/intern/versioning_defaults.c
index c2e2d19d883..bc1ff353665 100644
--- a/source/blender/blenloader/intern/versioning_defaults.c
+++ b/source/blender/blenloader/intern/versioning_defaults.c
@@ -277,8 +277,12 @@ void BLO_update_defaults_startup_blend(Main *bmain, const char *app_template)
scene->r.cfra = 1.0f;
scene->r.displaymode = R_OUTPUT_WINDOW;
- /* AV Sync break physics sim caching, disable until that is fixed. */
- if (!(app_template && STREQ(app_template, "Video_Editing"))) {
+ if (app_template && STREQ(app_template, "Video_Editing")) {
+ /* Filmic is too slow, use default until it is optimized. */
+ STRNCPY(scene->view_settings.view_transform, "Default");
+ }
+ else {
+ /* AV Sync break physics sim caching, disable until that is fixed. */
scene->audio.flag &= ~AUDIO_SYNC;
scene->flag &= ~SCE_FRAME_DROP;
}